import numpy as np


def calc_spi_analysis(results, data):
    do_spi_analysis = results.get("do_spi_analysis", False)
    if not do_spi_analysis:
        return

    for k in ("spi_threshold_photon", "spi_threshold_hit_percentage", "roi_x1", "roi_x2", "roi_y1", "roi_y2"):
        if k not in results:
            return

    spi_threshold_photon         = results["spi_threshold_photon"]
    spi_threshold_hit_percentage = results["spi_threshold_hit_percentage"]

    roi_x1 = results["roi_x1"]
    roi_x2 = results["roi_x2"]
    roi_y1 = results["roi_y1"]
    roi_y2 = results["roi_y2"]

    if len(roi_x1) == 0:
        return

    if not (len(roi_x1) == len(roi_x2) == len(roi_y1) == len(roi_y2)):
        return

    nphotons = 0
    npixels = 0

    for ix1, ix2, iy1, iy2 in zip(roi_x1, roi_x2, roi_y1, roi_y2):
        data_roi = data[iy1:iy2, ix1:ix2]
        nphotons += np.sum(data_roi > spi_threshold_photon)
        npixels += data_roi.size

    photon_percentage = nphotons / npixels * 100
    hit = (photon_percentage > spi_threshold_hit_percentage)

    results["number_of_spots"] = photon_percentage
    results["is_hit_frame"] = bool(hit) # json does not like numpy bool_ scalars



